@@ -1,7 +1,5 @@
 package SQL::Translator::Producer::DB2;
 
-# -------------------------------------------------------------------
-# $Id: DB2.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -38,7 +36,8 @@ Creates an SQL DDL suitable for DB2.
 
 use warnings;
 use strict;
-use vars qw[ $DEBUG $WARN ];
+use vars qw[ $VERSION $DEBUG $WARN ];
+$VERSION = '1.59';
 $DEBUG   = 0 unless defined $DEBUG;
 
 use SQL::Translator::Schema::Constants;
