@@ -1,7 +1,5 @@
 package SQL::Translator::Producer::DiaUml;
 
-# -------------------------------------------------------------------
-# $Id: DiaUml.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -58,7 +56,8 @@ automatically arrange them horizontally or vertically.
 
 use strict;
 
-use vars qw[ $DEBUG @EXPORT_OK ];
+use vars qw[ $DEBUG $VERSION @EXPORT_OK ];
+$VERSION = '1.59';
 $DEBUG   = 0 unless defined $DEBUG;
 
 use SQL::Translator::Utils 'debug';
