@@ -1,7 +1,5 @@
 package SQL::Translator::Schema;
 
-# ----------------------------------------------------------------------
-# $Id: Schema.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -56,7 +54,9 @@ use SQL::Translator::Schema::View;
 use SQL::Translator::Utils 'parse_list_arg';
 
 use base 'SQL::Translator::Schema::Object';
-use vars qw[ $TABLE_ORDER $VIEW_ORDER $TRIGGER_ORDER $PROC_ORDER ];
+use vars qw[ $VERSION $TABLE_ORDER $VIEW_ORDER $TRIGGER_ORDER $PROC_ORDER ];
+
+$VERSION = '1.59';
 
 __PACKAGE__->_attributes(qw/name database translator/);
 
