@@ -1,7 +1,5 @@
 package SQL::Translator::Schema::Constraint;
 
-# ----------------------------------------------------------------------
-# $Id: Constraint.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -49,7 +47,9 @@ use SQL::Translator::Utils 'parse_list_arg';
 
 use base 'SQL::Translator::Schema::Object';
 
-use vars qw($TABLE_COUNT $VIEW_COUNT);
+use vars qw($VERSION $TABLE_COUNT $VIEW_COUNT);
+
+$VERSION = '1.59';
 
 my %VALID_CONSTRAINT_TYPE = (
     PRIMARY_KEY, 1,
