@@ -1,7 +1,5 @@
 package SQL::Translator::Schema::Field;
 
-# ----------------------------------------------------------------------
-# $Id: Field.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -48,7 +46,9 @@ use SQL::Translator::Utils 'parse_list_arg';
 
 use base 'SQL::Translator::Schema::Object';
 
-use vars qw($TABLE_COUNT $VIEW_COUNT);
+use vars qw($VERSION $TABLE_COUNT $VIEW_COUNT);
+
+$VERSION = '1.59';
 
 # Stringify to our name, being careful not to pass any args through so we don't
 # accidentally set it to undef. We also have to tweak bool so the object is
