@@ -1,7 +1,5 @@
 package SQL::Translator::Utils;
 
-# ----------------------------------------------------------------------
-# $Id: Utils.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -22,12 +20,13 @@ package SQL::Translator::Utils;
 
 use strict;
 use base qw(Exporter);
-use vars qw($DEFAULT_COMMENT @EXPORT_OK);
+use vars qw($VERSION $DEFAULT_COMMENT @EXPORT_OK);
 
 use Digest::SHA1 qw( sha1_hex );
 
 use Exporter;
 
+$VERSION = '1.59';
 $DEFAULT_COMMENT = '-- ';
 @EXPORT_OK = qw(
     debug normalize_name header_comment parse_list_arg truncate_id_uniquely $DEFAULT_COMMENT parse_mysql_version
